@@ -1,7 +1,8 @@
 from ..containers import KeyEnforcer
-from ..hooks import DANNHook, GVBHook
+from ..hooks import CDANNEHook, DANNEHook, DANNHook, GVBEHook, GVBHook
 from ..layers import ModelWithBridge
 from .base_adapter import BaseGCDAdapter
+from .gan import CDAN
 
 
 class DANN(BaseGCDAdapter):
@@ -15,6 +16,14 @@ class DANN(BaseGCDAdapter):
         self.hook = self.hook_cls(opts=list(self.optimizers.values()), **hook_kwargs)
 
 
+class DANNE(DANN):
+    hook_cls = DANNEHook
+
+
+class CDANNE(DANN, CDAN):
+    hook_cls = CDANNEHook
+
+
 class GVB(DANN):
     """
     Wraps [GVBHook][pytorch_adapt.hooks.gvb].
@@ -28,3 +37,7 @@ class GVB(DANN):
             if not isinstance(models[k], ModelWithBridge):
                 models[k] = ModelWithBridge(models[k])
         super().init_containers_and_check_keys()
+
+
+class GVBE(GVB):
+    hook_cls = GVBEHook
